@@ -1,6 +1,6 @@
 # Copyright Notice:
 # Copyright 2016 DMTF. All rights reserved.
-# License: BSD 3-Clause License. For full text see link: https://github.com/DMTF/Redfishtool/blob/master/LICENSE.md
+# License: BSD 3-Clause License. For full text see link: https://github.com/DMTF/Redfishtool/blob/main/LICENSE.md
 
 # redfishtool: Systems.py
 #
@@ -584,7 +584,13 @@ class RfSystemsOperations():
                 return(8,None,False,None)
             
             #form the patch data
-            patchData={"Boot": {"BootSourceOverrideEnabled": enabledVal, "BootSourceOverrideTarget": targetVal } }
+
+            # Get the value of "BootSourceOverrideTarget" property and pass it in the patch request.
+            # Some HW vendors need this property to be passed explicitly.
+            if "BootSourceOverrideMode" in d["Boot"]:
+                patchData={"Boot": {"BootSourceOverrideEnabled": enabledVal, "BootSourceOverrideTarget": targetVal, "BootSourceOverrideMode": d["Boot"]["BootSourceOverrideMode"] } }
+            else:
+                patchData={"Boot": {"BootSourceOverrideEnabled": enabledVal, "BootSourceOverrideTarget": targetVal } }
 
             #call the generic patch command to send the patch.  This takes care of etag support
             rc,r,j,d=rft.patchResource(rft, r, patchData)
