@@ -1,6 +1,6 @@
 # Copyright Notice:
 # Copyright 2016 DMTF. All rights reserved.
-# License: BSD 3-Clause License. For full text see link: https://github.com/DMTF/Redfishtool/blob/master/LICENSE.md
+# License: BSD 3-Clause License. For full text see link: https://github.com/DMTF/Redfishtool/blob/main/LICENSE.md
 
 # redfishtool:  redfishtoolTransport.py
 #
@@ -60,8 +60,8 @@ class RfTransport():
     def __init__(self):
         # constant parameters-- these dont change and are not updated
         self.program="redfishtool"              # program name (in case we want to change it)
-        self.version="1.1.6"                    # this redfishtool version
-        self.releaseDate="06/20/2022"           # release date for this version of redfishtool
+        self.version="1.1.8"                    # this redfishtool version
+        self.releaseDate="08/16/2023"           # release date for this version of redfishtool
         self.downloadFrom="https://github.com/DMTF/Redfishtool" # where to find redfishtool
         self.magic="12345"                      # used for debug to test for a known parameter in this object
         self.UNAUTHENTICATED_API=1              # unauthenticated API that doesn't send credentials in body data
@@ -1008,7 +1008,7 @@ class RfTransport():
 
         elif(rft.gotMatchOptn):
             baseUrl=r.url
-            matchedPath=None
+            matchedPath,matchedRc,matchedR,matchedJ,matchedD=None,1,None,False,None
             matches=0
             for i in range (0,numOfLinks):
                 if( '@odata.id'  not in coll['Members'][i] ):
@@ -1019,13 +1019,13 @@ class RfTransport():
                     rc,r,j,d=rft.rftSendRecvRequest(rft.AUTHENTICATED_API, 'GET', baseUrl, relPath=path)
                     if(rc==0):  # if matchProp found
                         if( d[rft.matchProp] == rft.matchValue ):
-                            matchedPath=path
+                            matchedPath,matchedRc,matchedR,matchedJ,matchedD=path,rc,r,j,d
                             matches +=1
                             if( matches > 1 ):
                                 rft.printErr("Error: getPathBy --Id or --Match option: failed: found multiple matches.")
                                 return(None,1,None,False,None)
                             if(rft.firstOptn):
-                                return(matchedPath,rc,r,j,d)
+                                return(matchedPath,matchedRc,matchedR,matchedJ,matchedD)
                         else:
                             rft.printVerbose(4,"Transport:getPathBy:Match: failed match: matchProp={}, matchValue={}, readValue={}".format(rft.matchProp,rft.matchValue,d[rft.matchProp]))
                             pass
@@ -1035,7 +1035,7 @@ class RfTransport():
             #after looping over all members in the array,
             #if here, if we got a match, return the path.  If not, then no match was found. return none
             if( matches > 0 ):
-                return(matchedPath,rc,r,j,d)
+                return(matchedPath,matchedRc,matchedR,matchedJ,matchedD)
             else:
                 rft.printErr("Error: getPathBy --Id or --Match option: no match found in collection")
                 return(None,1,None,False,None)
